==> haskell-prettyprinter-convert-ansi-wl-pprint-1.1-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-convert-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyprinter-convert-ansi-wl-pprint
version:              1.1
visibility:           public
id:
    prettyprinter-convert-ansi-wl-pprint-1.1-DPEOV7Pivoo6MIn64oChwL

key:
    prettyprinter-convert-ansi-wl-pprint-1.1-DPEOV7Pivoo6MIn64oChwL

license:              BSD-2-Clause
maintainer:           David Luposchainsky <dluposchainsky at google>
author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:
    Converter from »ansi-wl-pprint« documents to »prettyprinter«-based ones.

description:          See README.md
category:             User Interfaces, Text
abi:                  4885fa3fba5694ceb24c3fa46d6f4084
exposed:              True
exposed-modules:      Data.Text.Prettyprint.Convert.AnsiWlPprint
import-dirs:
    /usr/lib/ghc-8.8.1/site-local/prettyprinter-convert-ansi-wl-pprint-1.1

library-dirs:
    /usr/lib/ghc-8.8.1/site-local/prettyprinter-convert-ansi-wl-pprint-1.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.8.1/prettyprinter-convert-ansi-wl-pprint-1.1

hs-libraries:
    HSprettyprinter-convert-ansi-wl-pprint-1.1-DPEOV7Pivoo6MIn64oChwL

depends:
    ansi-terminal-0.10.2-HhJCIibw6rY8DtJJgZqOOO
    ansi-wl-pprint-0.6.9-CmSsQRvrrm6d6b5cu8pHd base-4.13.0.0
    prettyprinter-1.3.0-9W5NSFrbbf46xXVxODdG9f
    prettyprinter-ansi-terminal-1.1.1.2-3rTWzx416SGIYhWgdsf7gh
    text-1.2.4.0

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html/prettyprinter-convert-ansi-wl-pprint.haddock

haddock-html:
    /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-convert-ansi-wl-pprint-1.1-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-convert-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyprinter-convert-ansi-wl-pprint
version:              1.1
visibility:           public
id:
    prettyprinter-convert-ansi-wl-pprint-1.1-DVrUs3TIEZXB6XJ44NeIFS

key:
    prettyprinter-convert-ansi-wl-pprint-1.1-DVrUs3TIEZXB6XJ44NeIFS

license:              BSD-2-Clause
maintainer:           David Luposchainsky <dluposchainsky at google>
author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:
    Converter from »ansi-wl-pprint« documents to »prettyprinter«-based ones.

description:          See README.md
category:             User Interfaces, Text
abi:                  6125ed7b402e6228e550a4d885126eff
exposed:              True
exposed-modules:      Data.Text.Prettyprint.Convert.AnsiWlPprint
import-dirs:
    /usr/lib/ghc-8.8.3/site-local/prettyprinter-convert-ansi-wl-pprint-1.1

library-dirs:
    /usr/lib/ghc-8.8.3/site-local/prettyprinter-convert-ansi-wl-pprint-1.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.8.3/prettyprinter-convert-ansi-wl-pprint-1.1

hs-libraries:
    HSprettyprinter-convert-ansi-wl-pprint-1.1-DVrUs3TIEZXB6XJ44NeIFS

depends:
    ansi-terminal-0.10.3-2mLj4sTjIwVaqOtXn4TV8
    ansi-wl-pprint-0.6.9-IPiGHP9GLtPHE2cRX17Xjs base-4.13.0.0
    prettyprinter-1.5.0-EYbhRR8P27MLxzBVqwtqjc
    prettyprinter-ansi-terminal-1.1.1.2-4zkEblsrWKNtJdkDZdcah
    text-1.2.4.0

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html/prettyprinter-convert-ansi-wl-pprint.haddock

haddock-html:
    /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
